import{Z as d}from"./jwt-decode.esm.32f71954.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="5b2f5d29-ea12-4fb0-9600-299aad1277db",e._sentryDebugIdIdentifier="sentry-dbid-5b2f5d29-ea12-4fb0-9600-299aad1277db")}catch{}})();function h(e){return d.string().email().safeParse(e).success}function p(e){return e.charAt(0).toUpperCase()+e.slice(1)}function w(e,t,r=!1,a=!0,s=!1,n=!0){const o=(a?e.toLocaleLowerCase():e).normalize("NFD").replace(/[\u0300-\u036f]/g,""),i=`a-zA-Z0-9${s?"/":""}${n?"-":""}`,c=new RegExp(`[^${i}]`,"g"),l=o.replace(c,"_"),u=r?l:l.replace(/_+/g,"_");return t?u:u.replace(/_$/,"")}function b(e){var n;const r=e.toLocaleLowerCase().trim().normalize("NFD").replace(/[\u0300-\u036f]/g,""),a=/[a-z0-9]+/g,s=r.match(a);return(n=s==null?void 0:s.join("-"))!=null?n:""}function m(e,t){if(e.length===0||t.length===0)return!1;const r=e.toLowerCase(),a=t.toLowerCase();return r.split("").reduce((n,f)=>{var i;if(n===!1)return!1;const o=(i=n[n.length-1])!=null?i:null;if(o===null){const c=a.indexOf(f);return c===-1?!1:[c]}else{const l=a.slice(o+1).indexOf(f);return l===-1?!1:[...n,o+1+l]}},[])}function y(e){let t=0;for(let r=0;r<e.length;r++){const a=e.charCodeAt(r);t=(t<<5)-t+a,t=t&t}return t}export{w as a,p as c,m as f,y as h,h as i,b as n};
//# sourceMappingURL=string.ff0b4ef9.js.map
