import{O as l}from"./workspaceStore.5dfe5329.js";import{d as c,U as f,ac as u,f as n,b as o,u as a,o as _,g as r,t as i,i as s,A as p,df as g}from"./jwt-decode.esm.32f71954.js";import"./userStore.339db438.js";import"./url.79cc02c3.js";import"./colorHelpers.b41220cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f7d5380d-54c8-40cc-9020-50f4a45285a4",e._sentryDebugIdIdentifier="sentry-dbid-f7d5380d-54c8-40cc-9020-50f4a45285a4")}catch{}})();const v=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new l().loginCallback()}),(t,d)=>(_(),u("div",null,[n(a(p),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(a(g),null,{default:o(()=>[r(i(a(s).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{v as default};
//# sourceMappingURL=OidcLoginCallback.17eeec42.js.map
