import{O as s}from"./OmniChat.fb0615b3.js";import{u as a}from"./omniChatStore.10d769d2.js";import{d as c,ei as i,u as t,o as u,a as l,h as d}from"./jwt-decode.esm.32f71954.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="a87a8977-924a-4a92-8c8f-59b8b05c43b3",e._sentryDebugIdIdentifier="sentry-dbid-a87a8977-924a-4a92-8c8f-59b8b05c43b3")}catch{}})();const _=c({__name:"ConsoleOmniChat",setup(e){const n=i().params.projectId,o=a();return o.init("console",n),(p,f)=>t(o).controller&&t(o).repository?(u(),l(s,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)},"show-console-suggestions":!0},null,8,["ai-chat-repository","controller","environment"])):d("",!0)}});export{_};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.cbe8dd45.js.map
