import{k as r}from"./router.29e08ea4.js";import"./jwt-decode.esm.32f71954.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="e8b29ce5-ba86-4514-8020-2ee55d7178a4",n._sentryDebugIdIdentifier="sentry-dbid-e8b29ce5-ba86-4514-8020-2ee55d7178a4")}catch{}})();class o{async list(e){return r.get(`organizations/${e}/folders`)}async create(e){return r.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async checkNameAvailability(e,a){return r.post(`organizations/${e}/folders/name-available`,{folderName:a})}async delete(e,a){return r.delete(`organizations/${e}/folders/${a}`)}async update(e,a){return r.patch(`organizations/${e}/folders/${a.id}/`,{name:a.name,memberIds:a.memberIds})}}export{o as F};
//# sourceMappingURL=folder.bd31d9bc.js.map
