import{L as t}from"./Logo.c75e45a8.js";import{d as n,o as r,a as d,u as i}from"./jwt-decode.esm.32f71954.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="1f8517a0-9af9-4226-a541-7136b1a1799e",e._sentryDebugIdIdentifier="sentry-dbid-1f8517a0-9af9-4226-a541-7136b1a1799e")}catch{}})();const f="/assets/logo.0faadfa2.svg",p=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(a,o)=>{var s;return r(),d(t,{"image-url":i(f),"brand-name":"Abstra","hide-text":a.hideText,size:(s=a.size)!=null?s:"small"},null,8,["image-url","hide-text","size"])}}});export{p as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.f0472c1e.js.map
