import{d as a,o as d,ac as s,e as c,ae as l,eh as n,_ as r}from"./jwt-decode.esm.32f71954.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="51422dc9-7e61-4d3c-8a17-9cab8cd821ac",t._sentryDebugIdIdentifier="sentry-dbid-51422dc9-7e61-4d3c-8a17-9cab8cd821ac")}catch{}})();const i=a({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(t){return(e,o)=>(d(),s("div",{class:n(["content-layout",{"no-padding":e.noPadding}])},[c("div",{class:n(["centered-layout",{"full-width":e.fullWidth}])},[l(e.$slots,"default",{},void 0,!0)],2)],2))}});const _=r(i,[["__scopeId","data-v-fb4d67f9"]]);export{_ as C};
//# sourceMappingURL=ContentLayout.b1b0e8fb.js.map
