import{W as c,dQ as i,dR as d}from"./jwt-decode.esm.32f71954.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="cb865416-8a3a-4fbb-8f7a-f42eb2fba69d",e._sentryDebugIdIdentifier="sentry-dbid-cb865416-8a3a-4fbb-8f7a-f42eb2fba69d")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:a,YearPicker:f,TimePicker:b,QuarterPicker:r,RangePicker:o}=i(d),u=c(n,{WeekPicker:t,MonthPicker:a,YearPicker:f,RangePicker:o,TimePicker:b,QuarterPicker:r,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e)});export{u as D,a as M,r as Q,o as R,t as W};
//# sourceMappingURL=dayjs.68053597.js.map
