import{_ as i,C as n}from"./View.vue_vue_type_script_setup_true_lang.f7c2ef15.js";import{d as p,ei as s,a,u as m,o as d}from"./jwt-decode.esm.32f71954.js";import"./router.29e08ea4.js";import"./index.2400150a.js";import"./fetch.a8fb4ba0.js";import"./record.41c9caee.js";import"./SaveButton.813aaf8d.js";import"./ExclamationCircleOutlined.380af12e.js";import"./CrudView.ca91f805.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.c50f6a0a.js";import"./constants.b5d83622.js";import"./url.79cc02c3.js";import"./PhDotsThreeVertical.vue.e305b3a2.js";import"./index.c59ca45b.js";import"./asyncComputed.f9fa4c71.js";import"./omniChatStore.10d769d2.js";import"./uuid.77e093c3.js";import"./PhCopySimple.vue.7cacc0f7.js";import"./PhPencil.vue.e0099a7f.js";import"./useCodebaseEvents.5fbf9bc1.js";import"./contracts.generated.c5043d35.js";import"./index.a4dc5332.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="457ed5ba-5522-4cf0-b9b7-08599b9cd6aa",o._sentryDebugIdIdentifier="sentry-dbid-457ed5ba-5522-4cf0-b9b7-08599b9cd6aa")}catch{}})();const A=p({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new n(t);return(c,f)=>(d(),a(i,{"env-var-repository":m(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.84ca50aa.js.map
