import{d,c as o,o as i,ac as u,e as c,ae as y,ad as a,eh as r}from"./jwt-decode.esm.32f71954.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="12ad1ce7-0791-4260-a206-ec2581884738",e._sentryDebugIdIdentifier="sentry-dbid-12ad1ce7-0791-4260-a206-ec2581884738")}catch{}})();const S=d({__name:"ScrollArea",props:{innerClass:{},outerClass:{},outerStyle:{},innerStyle:{}},setup(e){const t=e,n=o(()=>t.outerStyle?{position:"relative",...t.outerStyle}:{position:"relative"}),l=o(()=>{var s;return{position:"absolute",inset:0,overflow:"auto",...(s=t.innerStyle)!=null?s:{}}});return(s,p)=>(i(),u("div",{style:a(n.value),class:r(s.outerClass)},[c("div",{style:a(l.value),class:r(s.innerClass)},[y(s.$slots,"default")],6)],6))}});export{S as _};
//# sourceMappingURL=ScrollArea.vue_vue_type_script_setup_true_lang.e8269806.js.map
