import{_ as f}from"./Login.vue_vue_type_script_setup_true_lang.6f146a14.js";import{d as l,ec as m,ei as g,ac as y,f as b,u as a,o as w,_ as k}from"./jwt-decode.esm.32f71954.js";import{u as h}from"./workspaceStore.5dfe5329.js";import"./CircularLoading.26cebe64.js";import"./Logo.c75e45a8.js";import"./string.ff0b4ef9.js";import"./index.a4dc5332.js";import"./userStore.339db438.js";import"./url.79cc02c3.js";import"./colorHelpers.b41220cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="ceff727d-7de8-4345-9dbf-3dd4de507d11",e._sentryDebugIdIdentifier="sentry-dbid-ceff727d-7de8-4345-9dbf-3dd4de507d11")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=m(),t=g(),r=h(),_=async()=>{const{redirect:s,...n}=t.query;if(s){await o.push({path:s,query:n,params:t.params});return}o.push({name:"playerHome",query:n})};return(s,n)=>{var d,c,p,u,i;return w(),y("div",v,[b(f,{"logo-url":(c=(d=a(r).state.workspace)==null?void 0:d.logoUrl)!=null?c:void 0,"brand-name":(p=a(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=a(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-12c690e1"]]);export{H as default};
//# sourceMappingURL=Login.90ebb0f6.js.map
