import{P as m}from"./PlayerNavbar.fd53d29e.js";import{d as g,ec as h,ei as c,r as y,c as b,j as k,ac as v,u as n,a as w,h as L,e as C,f as I,o as i,_ as N}from"./jwt-decode.esm.32f71954.js";import{u as V}from"./workspaceStore.5dfe5329.js";import"./userStore.339db438.js";import"./metadata.c5f500d1.js";import"./PhWebhooksLogo.vue.13c489ce.js";import"./LoadingOutlined.6f7bdc44.js";import"./PhSignOut.vue.4f6997f5.js";import"./index.5ecb9a37.js";import"./url.79cc02c3.js";import"./colorHelpers.b41220cb.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="867efb54-fb7a-46af-ac69-aadaf3c162ea",a._sentryDebugIdIdentifier="sentry-dbid-867efb54-fb7a-46af-ac69-aadaf3c162ea")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(a){const e=h(),o=V(),u=c().path,t=y(null),d=async({path:s,id:r})=>{t.value=r,await e.push({path:`/${s}`}),t.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(s,r)=>{const f=k("RouterView");return i(),v("div",x,[n(o).state.workspace?(i(),w(m,{key:0,"current-path":n(u),"hide-login":_.value,"runner-data":n(o).state.workspace,loading:t.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(f)])])}}});const F=N(D,[["__scopeId","data-v-f095bece"]]);export{F as default};
//# sourceMappingURL=Main.6fd4bb0a.js.map
