import{d as y,c as b,a as r,b as a,u as n,eG as d,ed as g,o as i,f as l,dj as p,ae as u,h as c,eH as m,bY as f,b0 as _}from"./jwt-decode.esm.32f71954.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="d406135b-b8ca-42f3-b555-aac3c685cf2d",t._sentryDebugIdIdentifier="sentry-dbid-d406135b-b8ca-42f3-b555-aac3c685cf2d")}catch{}})();const h=y({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(t){const e=t,s=b(()=>e.disabledTooltip&&e.disabled?e.disabledTooltip:e.tooltip);return(o,k)=>s.value?(i(),r(n(_),{key:0,title:s.value},{default:a(()=>[l(n(f),d(m(o.$props)),{default:a(()=>[l(n(p),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[o.loading?c("",!0):u(o.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"])):(i(),r(n(f),d(g({key:1},o.$props)),{default:a(()=>[l(n(p),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[o.loading?c("",!0):u(o.$slots,"default",{key:0})]),_:3})]),_:3},16))}});export{h as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.9c0844e1.js.map
