import{i as k}from"./metadata.c5f500d1.js";import{W as v}from"./Watermark.6e692419.js";import{F as w}from"./PhArrowSquareOut.vue.5a8d2f86.js";import{d as x,ec as b,c as C,r as D,u as e,ac as m,f as p,b as r,h as I,o as a,a as n,g as f,t as _,i as z,T as y,aY as F,ej as T,dj as g,el as j,eh as B,_ as H}from"./jwt-decode.esm.32f71954.js";import{u as L}from"./workspaceStore.5dfe5329.js";import"./index.dfc79bf7.js";import{L as N}from"./LoadingOutlined.6f7bdc44.js";import{C as S}from"./Card.e1ec3051.js";import"./PhWebhooksLogo.vue.13c489ce.js";import"./constants.b5d83622.js";import"./userStore.339db438.js";import"./url.79cc02c3.js";import"./colorHelpers.b41220cb.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="2059c942-5a77-48dc-85ed-ce6ae89e4675",o._sentryDebugIdIdentifier="sentry-dbid-2059c942-5a77-48dc-85ed-ce6ae89e4675")}catch{}})();const V={key:0,class:"home-container"},W=x({__name:"Home",setup(o){const i=b(),l=L(),u=C(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(d=>d.id!=="home"))||[]}),c=D(null),h=async(s,d)=>{c.value=d,await i.push({path:`/${s}`}),c.value=null};return(s,d)=>e(l).state.workspace?(a(),m("div",V,[p(e(g),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(a(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(_(e(z).translate("i18n_home_no_forms_available")),1)]),_:1})):(a(!0),m(F,{key:1},T(u.value,t=>(a(),n(e(S),{key:t.id,class:B(["form-card",{loading:c.value===t.id}]),"body-style":{cursor:"pointer"},onClick:E=>h(t.path,t.id)},{default:r(()=>[p(e(g),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(a(),n(j(e(k)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(_(t.name),1)]),_:2},1024),c.value!==t.id?(a(),n(e(w),{key:0,size:"20"})):(a(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(v,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):I("",!0)}});const X=H(W,[["__scopeId","data-v-2dd12c4e"]]);export{X as default};
//# sourceMappingURL=Home.bad5d80b.js.map
