import{O as l}from"./workspaceStore.5dfe5329.js";import{d as c,U as u,ac as f,f as o,b as n,u as a,o as _,g as r,t as d,i as s,A as b,df as p}from"./jwt-decode.esm.32f71954.js";import"./userStore.339db438.js";import"./url.79cc02c3.js";import"./colorHelpers.b41220cb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ad6fd989-e35b-4b02-8127-730d99c5ce9c",e._sentryDebugIdIdentifier="sentry-dbid-ad6fd989-e35b-4b02-8127-730d99c5ce9c")}catch{}})();const v=c({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new l().logoutCallback()}),(t,i)=>(_(),f("div",null,[o(a(b),null,{default:n(()=>[r(d(a(s).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(a(p),null,{default:n(()=>[r(d(a(s).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{v as default};
//# sourceMappingURL=OidcLogoutCallback.b4d1c600.js.map
