import{d as _,ec as f,ei as m,i as n,o as c,a as p,b as i,ac as g,ej as y,f as v,e as k,t as w,u as r,aY as I}from"./jwt-decode.esm.32f71954.js";import{A as T,T as D}from"./Card.e1ec3051.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="9ab92d4e-36d1-44ea-b4c7-f60a87ac89ce",e._sentryDebugIdIdentifier="sentry-dbid-9ab92d4e-36d1-44ea-b4c7-f60a87ac89ce")}catch{}})();const x=_({__name:"TablesTabs",setup(e){const a=f(),t=m(),d=String(t.name),u=t.params.projectId,l=[{label:n.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:n.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:n.translate("i18n_tablestabs_run_sql"),value:"sql"}],b=o=>{a.push({name:String(o),params:{projectId:u}})};return(o,h)=>(c(),p(r(D),{"active-key":r(d),options:l,"onUpdate:activeKey":b},{default:i(()=>[(c(),g(I,null,y(l,s=>v(r(T),{key:s.value,name:s.value},{tab:i(()=>[k("span",null,w(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{x as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.744da918.js.map
