import{C as n,D as r,E as o,F as d,P as c,G as p,H as m,I as u,J as a,K as f,L as b,N as g,O as l}from"./jwt-decode.esm.32f71954.js";import{a as y,b as i}from"./router.235ae730.js";import{s as w}from"./workspaceStore.5dfe5329.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang.7b340da5.js";import"./userStore.339db438.js";import"./url.79cc02c3.js";import"./colorHelpers.b41220cb.js";import"./PlayerConfigProvider.d0d5439f.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="2273cd3e-6501-4db4-9327-5d0d3d8ab992",t._sentryDebugIdIdentifier="sentry-dbid-2273cd3e-6501-4db4-9327-5d0d3d8ab992")}catch{}})();class I{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await y(),s=n(),e=r({render:()=>f(h)});o.init(),d(e,i,t),I.init(),e.use(i),e.use(s),e.use(c),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",m),e.component("Message",u),a(e,b),a(e,g),a(e,l)})();
//# sourceMappingURL=player.66868a86.js.map
