import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.f0472c1e.js";import{B as m}from"./BaseLayout.fed5adb7.js";import{d as l,al as y,c8 as b,_ as u,b4 as v,b5 as g,o as _,ac as h,e as a,ad as n,ei as w,ec as S,U as L,a as k,b as s,f as i,u as x}from"./jwt-decode.esm.32f71954.js";import{u as B}from"./editor.a00709d8.js";import{A as I}from"./index.ab7dc629.js";import"./Logo.c75e45a8.js";import"./router.235ae730.js";import"./workspaceStore.5dfe5329.js";import"./userStore.339db438.js";import"./url.79cc02c3.js";import"./colorHelpers.b41220cb.js";import"./useCodebaseEvents.5fbf9bc1.js";import"./contracts.generated.c5043d35.js";import"./index.2400150a.js";import"./constants.b5d83622.js";import"./linters.3b9f6de6.js";import"./asyncComputed.f9fa4c71.js";import"./Breadcrumb.ae24888f.js";import"./index.5ecb9a37.js";import"./index.c59ca45b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c50236c1-5fbc-49ef-8021-926bb8148c8d",e._sentryDebugIdIdentifier="sentry-dbid-c50236c1-5fbc-49ef-8021-926bb8148c8d")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=y({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(o)}}});const P={class:"v-spinner"};function D(e,o,r,c,d,p){return v((_(),h("div",P,[a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),a("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const R=u($,[["render",D],["__scopeId","data-v-06538001"]]),j={class:"content"},z=l({__name:"ProjectLogin",setup(e){const o=w(),r=S(),c=B();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),r.replace(t.pathname+t.search)}function p(){const t=o.query["api-key"];if(typeof t=="string")return t}return L(async()=>{const t=p();if(!t){r.push({name:"error"});return}await c.createLogin(t).then(d),r.push({name:"editor"})}),(t,A)=>(_(),k(m,null,{navbar:s(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:s(()=>[i(f)]),_:1})]),content:s(()=>[a("div",j,[i(R)])]),_:1}))}});const te=u(z,[["__scopeId","data-v-d2a19803"]]);export{te as default};
//# sourceMappingURL=ProjectLogin.9cec413b.js.map
