import{d as V,an as W,e7 as q,e8 as L,c as o,r as O,w as M,aX as X,f,W as m,aY as Y,aq as G,c_ as h,aC as j,bA as B,aT as H,ao as J}from"./jwt-decode.esm.32f71954.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},c=new Error().stack;c&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[c]="7e04ed91-c321-4a95-b2fe-1695192c234e",e._sentryDebugIdIdentifier="sentry-dbid-7e04ed91-c321-4a95-b2fe-1695192c234e")}catch{}})();const K={small:8,middle:16,large:24},Q=()=>({prefixCls:String,size:{type:[String,Number,Array]},direction:j.oneOf(B("horizontal","vertical")).def("horizontal"),align:j.oneOf(B("start","end","center","baseline")),wrap:H()});function U(e){return typeof e=="string"?K[e]:e||0}const r=V({compatConfig:{MODE:3},name:"ASpace",inheritAttrs:!1,props:Q(),slots:Object,setup(e,c){let{slots:l,attrs:g}=c;const{prefixCls:n,space:y,direction:w}=W("space",e),[E,F]=q(n),x=L(),s=o(()=>{var a,t,i;return(i=(a=e.size)!==null&&a!==void 0?a:(t=y==null?void 0:y.value)===null||t===void 0?void 0:t.size)!==null&&i!==void 0?i:"small"}),b=O(),u=O();M(s,()=>{[b.value,u.value]=(Array.isArray(s.value)?s.value:[s.value,s.value]).map(a=>U(a))},{immediate:!0});const z=o(()=>e.align===void 0&&e.direction==="horizontal"?"center":e.align),T=o(()=>J(n.value,F.value,`${n.value}-${e.direction}`,{[`${n.value}-rtl`]:w.value==="rtl",[`${n.value}-align-${z.value}`]:z.value})),k=o(()=>w.value==="rtl"?"marginLeft":"marginRight"),P=o(()=>{const a={};return x.value&&(a.columnGap=`${b.value}px`,a.rowGap=`${u.value}px`),m(m({},a),e.wrap&&{flexWrap:"wrap",marginBottom:`${-u.value}px`})});return()=>{var a,t;const{wrap:i,direction:R="horizontal"}=e,_=(a=l.default)===null||a===void 0?void 0:a.call(l),C=X(_),A=C.length;if(A===0)return null;const d=(t=l.split)===null||t===void 0?void 0:t.call(l),I=`${n.value}-item`,D=b.value,S=A-1;return f("div",G(G({},g),{},{class:[T.value,g.class],style:[P.value,g.style]}),[C.map((N,v)=>{let $=_.indexOf(N);$===-1&&($=`$$space-${v}`);let p={};return x.value||(R==="vertical"?v<S&&(p={marginBottom:`${D/(d?2:1)}px`}):p=m(m({},v<S&&{[k.value]:`${D/(d?2:1)}px`}),i&&{paddingBottom:`${u.value}px`})),E(f(Y,{key:$},[f("div",{class:I,style:p},[N]),v<S&&d&&f("span",{class:`${I}-split`,style:p},[d])]))})])}}});r.Compact=h;r.install=function(e){return e.component(r.name,r),e.component(h.name,h),e};const ee=r;export{ee as A};
//# sourceMappingURL=index.c59ca45b.js.map
