import{C as t,E as d,K as i,a as f,M as b,c,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.7b4a31db.js";import"./jwt-decode.esm.32f71954.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="6bf24d3c-a904-495f-bb6d-03e283c49641",e._sentryDebugIdIdentifier="sentry-dbid-6bf24d3c-a904-495f-bb6d-03e283c49641")}catch{}})();export{t as CancellationTokenSource,d as Emitter,i as KeyCode,f as KeyMod,b as MarkerSeverity,c as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.80ee55a4.js.map
