import{d as o,o as a,ac as s,f as d,u as c,S as _,_ as r}from"./jwt-decode.esm.32f71954.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="1590b75e-3486-44c0-9edb-c4ae06fcd7f6",e._sentryDebugIdIdentifier="sentry-dbid-1590b75e-3486-44c0-9edb-c4ae06fcd7f6")}catch{}})();const i={class:"centered"},f=o({__name:"LoadingContainer",setup(e){return(n,t)=>(a(),s("div",i,[d(c(_))]))}});const u=r(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.395f4c42.js.map
